@@ -20,6 +20,8 @@ use serde::ser::{SerializeStruct, Serializer};
 use std::borrow::Cow;
 use text_map_list::{UpdateTextMapList, TextMapListSynDataset};
 use ip_map_list::{UpdateIpMapList ,IpMapListSynDataset};
+use std::fmt;
+use std::cmp::Ordering;
 
 /// Common work datasets that allow a rapid development of rules and that the information of some logs allows enriching others.
 /// Other datasets like the ones associated with headquarters is controlled by the CMDB
@@ -84,7 +86,7 @@ pub enum SiemDataset {
     Secrets((Cow<'static, str>,TextMapSynDataset))
 }
 
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
 #[non_exhaustive]
 pub enum SiemDatasetType {
     /// Map IP to country, city, latitude and longitude
@@ -173,6 +175,31 @@ impl SiemDataset {
         }
     }
 }
+impl fmt::Display for SiemDataset {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "{:?}", self)
+        // or, alternatively:
+        // fmt::Debug::fmt(self, f)
+    }
+}
+impl PartialEq for SiemDataset {
+    fn eq(&self, other: &Self) -> bool {
+        self.dataset_type() == other.dataset_type()
+    }
+}
+impl Eq for SiemDataset {}
+
+impl PartialOrd for SiemDataset {
+    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
+        Some(self.cmp(other))
+    }
+}
+impl Ord for SiemDataset {
+    fn cmp(&self, other: &Self) -> Ordering {
+        self.dataset_type().cmp(&other.dataset_type())
+    }
+}
+
 
 impl Serialize for SiemDataset {
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
@@ -263,4 +290,4 @@ pub enum UpdateDataset {
     Configuration(UpdateTextMap),
     Secrets(UpdateTextMap),
     HostVulnerable(UpdateTextMapList)
-}
+}
\ No newline at end of file
